/*
 *  CPAPluginProtocols.h
 *  CocoaPacketAnalyzer
 *
 *
 *  Formal Protocol Interface Version 0.63
 *
 *
 *  Created by Jens Francke on 2009-08-13
 *  Copyright 2007-2009 Jens Francke. All rights reserved.
 *
 */

#import "CPANode.h"
#import "CPAPlugInsController.h"

/*  Notifications: 
 *  if the plugin defaults changed you can inform any active document to reload data from the datasources for the packet or detail view sending the above messages to the default NSNotificationCenter:
 */
#define kReloadPacketsView	@"CPAReloadPacketsViewDataNotification"
#define kReloadDetailsView	@"CPAReloadDetailsViewDataNotification"

/*
 *  Plugin Principal Class
 */
@protocol CPAPluginPrincipalClassProtocol
@required
- (id) initWithPlugInsController:(CPAPlugInsController*)plugInsController;
+ (NSString *) pluginTitle; 
@optional
+ (NSString *) pluginDescription; 
+ (NSString *) pluginVersion;
+ (NSString *) pluginAuthor;
@end



/*
 *  Analyzer Model Class
 */
@protocol CPAPluginAnalyzerProtocol
@required
- (id) initWithBytes:(const void *)bytes length:(uint16_t)length previousAnalyzer:(id)prevAnalyzer;
- (uint16_t) protocolSize;
- (NSArray *) protocolNodes;
- (NSString *) nextProtocol;
- (NSString *) protocolName;
- (NSString *) protocolInfo;
- (BOOL) hasPayload;
@end


/*  
 *  Plugin Preferences Controller Class
 */
@protocol CPAPluginPreferencesProtocol
@optional
- (NSWindow*) preferencesSheet;
- (BOOL) usesColor;
- (NSColor*) protocolColor;
@end
